Move the MinimumVersion property to the id path

Per feedback from the bmcweb maintainers, move the recently added
MinimumVersion property to the software/<functional-id>/ path since it's
tied to the BMC version.

Tested:
root@witherspoon:~# busctl
    get-property xyz.openbmc_project.Software.BMC.Updater
    /xyz/openbmc_project/software/26cddfb1
    xyz.openbmc_project.Software.MinimumVersion MinimumVersion
s "2.15.0"

Change-Id: I6c84d90282f4d58d0f776e9482d867208bbfe077
Signed-off-by: Adriana Kobylak <anoo@us.ibm.com>
diff --git a/item_updater.cpp b/item_updater.cpp
index 641a2a5..fad8c21 100644
--- a/item_updater.cpp
+++ b/item_updater.cpp
@@ -278,11 +278,19 @@
 
             auto path = fs::path(SOFTWARE_OBJPATH) / id;
 
             // Create functional association if this is the functional
             // version
             if (functional)
             {
                 createFunctionalAssociation(path);
+
+                if (minimum_ship_level::enabled())
+                {
+                    minimumVersionObject =
+                        std::make_unique<MinimumVersion>(bus, path);
+                    minimumVersionObject->minimumVersion(
+                        minimum_ship_level::getMinimumVersion());
+                }
             }
 
             AssociationList associations = {};
@@ -278,11 +278,19 @@
             auto path = fs::path(SOFTWARE_OBJPATH) / id;
 
-            // Create functional association if this is the functional
-            // version
+            // Create functional association and minimum ship level instance if
+            // this is the functional version
             if (functional)
             {